@@ -51,7 +51,6 @@
 package com.openexchange.spamsettings.generic.osgi;
 
 import javax.servlet.ServletException;
-import org.apache.commons.logging.Log;
 import org.osgi.service.http.HttpService;
 import org.osgi.service.http.NamespaceException;
 import com.openexchange.dispatcher.DispatcherPrefixService;
@@ -64,7 +63,7 @@ import com.openexchange.spamsettings.generic.servlet.SpamSettingsServlet;
  */
 public class SpamSettingsServletRegisterer {
 
-    private static final Log LOG = com.openexchange.log.Log.loggerFor(SpamSettingsServletRegisterer.class);
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(SpamSettingsServletRegisterer.class);
 
     /**
      * The {@link DefaultDeferringURLService} reference.
@@ -89,7 +88,7 @@ public class SpamSettingsServletRegisterer {
         try {
             final String alias = PREFIX.get().getPrefix() + SERVLET_PATH_APPENDIX;
             http_service.registerServlet(alias, new SpamSettingsServlet(), null, null);
-            LOG.info("Servlet " + alias + " registered.");
+            LOG.info("Servlet {} registered.", alias);
             SpamSettingsModulePreferences.setModule(true);
         } catch (final ServletException e) {
             LOG.error("Error registering spam settings servlet!", e);
@@ -108,7 +107,7 @@ public class SpamSettingsServletRegisterer {
         }
         final String alias = PREFIX.get().getPrefix() + SERVLET_PATH_APPENDIX;
         http_service.unregister(alias);
-        LOG.info("Servlet " + alias + "unregistered.");
+        LOG.info("Servlet {}unregistered.", alias);
     }
 
 }
